#!/bin/bash

PGM=`basename $0`
MYPID=$$
BASEDN="o=Rutgers Safeword,c=US"
THRESHOLD=3600
TIMEOUT=9

printUsage() {
    echo 'Usage: $PGM [-b BASEDN] [-t THRESHOLD (value in seconds)] [-T TIMEOUT (value in seconds)] hostnameOfProviderLDAPURI hostnameOfConsumerLDAPURI'
    exit 1
}

while getopts ":b:t:T:" opt; do
    case $opt in
        b  ) BASEDN=$OPTARG ;;
        t  ) THRESHOLD=$OPTARG ;;
        T  ) TIMEOUT=$OPTARG ;;
        \? ) printUsage
    esac
done
shift $(($OPTIND-1))

# Do we have 2 arguments?
[ $# -ne 2 ] && printUsage

# Are any args non-emtpy?
[ "$1" == '' ] || [ "$2" == '' ] && printUsage

PHOSTNAME=$1
CHOSTNAME=$2

RESULT=`/usr/lib64/nagios/plugins/rutgers/ldapSynchCheck.py -q -b "$BASEDN" -t $THRESHOLD -T $TIMEOUT ldap://$PHOSTNAME.rutgers.edu/ ldap://$CHOSTNAME.rutgers.edu/ 2>&1`

RETVAL=$?

if [ "$RETVAL" -eq "0" ]; then
    # Check for no output, perhaps provider LDAP server is the culprit
    echo $RESULT|grep -i "No output" >/dev/null
    if [ "$?" -eq "0" ]; then
        echo "Server $PHOSTNAME unavailable: No output" && exit 1
    else
        echo $RESULT && exit 0
    fi
elif [ "$RETVAL" -eq "1" ]; then
    # Check for no output again, perhaps provider LDAP server is the culprit
    echo $RESULT|grep -i "No output" >/dev/null
    [ "$?" -eq "0" ] && echo "Server $PHOSTNAME unavailable: No output" && exit 1

    # Check whether we received a SERVER_DOWN or TIMEOUT or ? type error msg
    # $RESULT might look something like: 
    # ldap.SERVER_DOWN: {'desc': "Can't contact LDAP server"}
    # OR
    # ldap.TIMEOUT: {'info': '', 'desc': 'Timed out'}
    echo $RESULT|grep "desc':" >/dev/null
    if [ "$?" -eq "0" ]; then
        # Basically strip everything before keyword 'desc'
        TMP=${RESULT#*desc\':}

        # Now strip } from the end
        DESC=${TMP%\}*}

        echo "Server $PHOSTNAME unavailable: $DESC" && exit 1
    else
        echo "Server $PHOSTNAME unavailable: Unknown problem" && exit 1
    fi
elif [ "$RETVAL" -eq "2" ]; then
    # Did the check timeout, well once again perhaps provider LDAP server is the culprit
    echo $RESULT|grep -i "Service Check Timed Out" >/dev/null
    if [ "$?" -eq "0" ]; then
        echo "Server $PHOSTNAME unavailable: Service Check Timed Out" && exit 1
    else
        echo $RESULT && exit 2
    fi
else
    echo $RESULT && exit 3
fi
